diff lisp/emacs-lisp/shadow.el @ 110924:a134abd52088

Rename another shadow.el function. * lisp/emacs-lisp/shadow.el (find-emacs-lisp-shadows): Rename it... (load-path-shadows-find): ... to this. (list-load-path-shadows): Update for above change.
author Glenn Morris <rgm@gnu.org>
date Fri, 08 Oct 2010 17:44:53 -0700
parents 3466369fdfcd
children 2316b868d5be 376148b31b5e
line wrap: on
line diff
--- a/lisp/emacs-lisp/shadow.el	Fri Oct 08 17:41:03 2010 -0700
+++ b/lisp/emacs-lisp/shadow.el	Fri Oct 08 17:44:53 2010 -0700
@@ -24,7 +24,7 @@
 
 ;;; Commentary:
 
 ;; The functions in this file detect (`find-emacs-lisp-shadows')
 ;; and display (`list-load-path-shadows') potential load-path
 ;; problems that arise when Emacs Lisp files "shadow" each other.
 ;;
@@ -65,7 +65,7 @@
   :type 'boolean
   :group 'lisp-shadow)
 
-(defun find-emacs-lisp-shadows (&optional path)
+(defun load-path-shadows-find (&optional path)
   "Return a list of Emacs Lisp files that create shadows.
 This function does the work for `list-load-path-shadows'.
 
@@ -141,6 +141,9 @@
     ;; Return the list of shadowings.
     shadows))
 
+(define-obsolete-function-alias 'find-emacs-lisp-shadows
+  'load-path-shadows-find "23.3")
+
 ;; Return true if neither file exists, or if both exist and have identical
 ;; contents.
 (defun load-path-shadows-same-file-or-nonexistent (f1 f2)
@@ -196,7 +199,7 @@
 considered to shadow a later file XXX.el, and vice-versa.
 
 Shadowings are located by calling the (non-interactive) companion
-function, `find-emacs-lisp-shadows'."
+function, `load-path-shadows-find'."
   (interactive)
   (let* ((path (copy-sequence load-path))
 	(tem path)
@@ -220,7 +223,7 @@
 		  (setq tem nil)))
 	    (setq tem (cdr tem)))))
 
-    (let* ((shadows (find-emacs-lisp-shadows path))
+    (let* ((shadows (load-path-shadows-find path))
 	   (n (/ (length shadows) 2))
 	   (msg (format "%s Emacs Lisp load-path shadowing%s found"
 			(if (zerop n) "No" (concat "\n" (number-to-string n)))
@@ -24,7 +24,7 @@
 ;;; Commentary:
 
-;; The functions in this file detect (`find-emacs-lisp-shadows')
+;; The functions in this file detect (`load-path-shadows-find')
 ;; and display (`list-load-path-shadows') potential load-path
 ;; problems that arise when Emacs Lisp files "shadow" each other.